summaryrefslogtreecommitdiff
path: root/nuttx/arch/arm/src/c5471
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-06-30 18:40:41 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-06-30 18:40:41 -0600
commit8ae1ef74551af33cf18dd1cc4188c4def4fecf42 (patch)
tree42db9eb61e43dd7bd958f080d08cbe6544793d5b /nuttx/arch/arm/src/c5471
parent8299f4051ce03e4c56c08c93a81af0c36e24a2f0 (diff)
downloadnuttx-8ae1ef74551af33cf18dd1cc4188c4def4fecf42.tar.gz
nuttx-8ae1ef74551af33cf18dd1cc4188c4def4fecf42.tar.bz2
nuttx-8ae1ef74551af33cf18dd1cc4188c4def4fecf42.zip
Rename uip_poll->devif_poll and uip_timer->devif_timer
Diffstat (limited to 'nuttx/arch/arm/src/c5471')
-rw-r--r--nuttx/arch/arm/src/c5471/c5471_ethernet.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/arch/arm/src/c5471/c5471_ethernet.c b/nuttx/arch/arm/src/c5471/c5471_ethernet.c
index 36efd78f9..cd29b2061 100644
--- a/nuttx/arch/arm/src/c5471/c5471_ethernet.c
+++ b/nuttx/arch/arm/src/c5471/c5471_ethernet.c
@@ -958,7 +958,7 @@ static int c5471_transmit(struct c5471_driver_s *c5471)
*
* Description:
* The transmitter is available, check if uIP has any outgoing packets ready
* to send. This is a callback from uip_poll(). uip_poll() may be called:
*
* 1. When the preceding TX packet send is complete,
* 2. When the preceding TX packet send timesout and the interface is reset
@@ -1403,7 +1403,7 @@ static void c5471_txdone(struct c5471_driver_s *c5471)
/* Then poll uIP for new XMIT data */
- (void)uip_poll(&c5471->c_dev, c5471_uiptxpoll);
+ (void)devif_poll(&c5471->c_dev, c5471_uiptxpoll);
}
/****************************************************************************
@@ -1522,7 +1522,7 @@ static void c5471_txtimeout(int argc, uint32_t arg, ...)
/* Then poll uIP for new XMIT data */
- (void)uip_poll(&c5471->c_dev, c5471_uiptxpoll);
+ (void)devif_poll(&c5471->c_dev, c5471_uiptxpoll);
}
/****************************************************************************
@@ -1554,7 +1554,7 @@ static void c5471_polltimer(int argc, uint32_t arg, ...)
{
/* If so, update TCP timing states and poll uIP for new XMIT data */
- (void)uip_timer(&c5471->c_dev, c5471_uiptxpoll, C5471_POLLHSEC);
+ (void)devif_timer(&c5471->c_dev, c5471_uiptxpoll, C5471_POLLHSEC);
}
/* Setup the watchdog poll timer again */
@@ -1715,7 +1715,7 @@ static int c5471_txavail(struct net_driver_s *dev)
{
/* If so, then poll uIP for new XMIT data */
- (void)uip_poll(&c5471->c_dev, c5471_uiptxpoll);
+ (void)devif_poll(&c5471->c_dev, c5471_uiptxpoll);
}
}
@@ -958,7 +958,7 @@ static int c5471_transmit(struct c5471_driver_s *c5471)
* Description:
* The transmitter is available, check if uIP has any outgoing packets ready
- * to send. This is a callback from uip_poll(). uip_poll() may be called:
+ * to send. This is a callback from devif_poll(). devif_poll() may be called:
*
* 1. When the preceding TX packet send is complete,